﻿using Android.App;
using Android.Widget;
using Android.OS;
using Com.Syncfusion.Charts;
using Android.Graphics;
using System.ComponentModel;
using System.Collections.ObjectModel;
using System;
using Android.Content;

namespace playground.Droid
{
    [Activity(Label = "playground", MainLauncher = true, Icon = "@mipmap/icon")]
    public class MainActivity : Activity
    {
        private ObservableCollection<ChartPoint> _data = new ObservableCollection<ChartPoint>();

        public SfChart _chart;
        public CategoryAxis _axis_primary;
        public NumericalAxis _axis_secondary;
        public FastLineSeries _lineSeries;

        protected override void OnCreate(Bundle savedInstanceState)
        {
            Syncfusion.Licensing.SyncfusionLicenseProvider.RegisterLicense("MzEzNzk2QDMxMzgyZTMyMmUzME5jcDVCVFUxSU5TUVVNU2RuekJZSVU4WjBROE56YWZYS3VKZkYzWlVOalE9");
            base.OnCreate(savedInstanceState);

            // Set our view from the "main" layout resource
            SetContentView(Resource.Layout.Main);

            
            _chart = FindViewById<SfChart>(Resource.Id.chart);
            create_primaryAxis();
            _chart.PrimaryAxis = _axis_primary;
            create_secondaryAxis();
            _chart.SecondaryAxis = _axis_secondary;
            create_lineSeries();
            
        }

        private void create_primaryAxis()
        {
            _axis_primary = new CategoryAxis();

            _axis_primary.AxisLineOffset = 10;
            _axis_primary.MajorGridLineStyle.StrokeWidth = 0;
            _axis_primary.MajorTickStyle.TickSize = 0;
            _axis_primary.MaximumLabels = 10;
            _axis_primary.LabelsIntersectAction = AxisLabelsIntersectAction.None;
            _axis_primary.LabelRotationAngle = -55;
            _axis_primary.LabelStyle.StrokeWidth = 0;
            _axis_primary.LabelStyle.TextColor = Color.Black;
            _axis_primary.LabelStyle.TextSize = 12;
            _axis_primary.LineStyle.StrokeWidth = 0;
            _axis_primary.ShowMajorGridLines = false;

            _chart.PrimaryAxis = _axis_primary;
        }

        private void create_secondaryAxis()
        {
            _axis_secondary = new NumericalAxis();

            int min = 0;
            int max = 25;

            _axis_secondary.MajorTickStyle.TickSize = 0;
            _axis_secondary.MajorGridLineStyle.StrokeWidth = 0;
            _axis_secondary.Maximum = max;
            _axis_secondary.Minimum = min;
            _axis_secondary.Visibility = Visibility.Gone;

            _chart.SecondaryAxis = _axis_secondary;
        }

        private void create_lineSeries()
        {
            try
            {
                _chart.Series.Clear();
                _chart.Annotations.Clear();

                _lineSeries = new FastLineSeries();

                _lineSeries.Color = Color.Black;

                _data.Add(new ChartPoint()
                {
                    Time = "9",
                    Value = 18,
                });


                _data.Add(new ChartPoint()
                {
                    Time = "10",
                    Value = 10,
                });

                _data.Add(new ChartPoint()
                {
                    Time = "11",
                    Value = 18
                });

                _data.Add(new ChartPoint()
                {
                    Time = "12",
                    Value = 20
                });

                _lineSeries.ItemsSource = _data;
                _lineSeries.XBindingPath = "Time";
                _lineSeries.YBindingPath = "Value";

                int x = 1;
                foreach (ChartPoint c in _data)
                {
                    _chart.Annotations.Add(CreateAnnotation(this, x, c.Value));
                    x++;
                }
                _lineSeries.SuspendNotification();
            }
            catch (Exception ex)
            {

            }

            _chart.Series.Add(_lineSeries);
            _chart.SuspendSeriesNotification();
        }

        public static ViewAnnotation CreateAnnotation(Context context, int x, double y)
        {
            ViewAnnotation annotation = new ViewAnnotation()
            {
                X1 = x,
                Y1 = y,
                VerticalAlignment = ChartAnnotationAlignment.Start,
            };

            // icon
            ImageView iconImage = new ImageView(context);
            iconImage.SetImageResource(Resource.Drawable.icon);


            // value
            TextView textView = new TextView(context);
            var value = y.ToString();
            textView.Text = value;
            if (value.Length > 6)
                textView.TextSize = 8;
            else if (value.Length > 4)
                textView.TextSize = 10;
            else
                textView.TextSize = 12;
            textView.TextAlignment = Android.Views.TextAlignment.Center;
            textView.Gravity = Android.Views.GravityFlags.CenterHorizontal;
            textView.SetPadding(0, 8, 0, 0);
            textView.SetTextColor(Color.Black);

            // container
            LinearLayout linearLayout = new LinearLayout(context);
            linearLayout.Orientation = Orientation.Vertical;
            linearLayout.SetPadding(5, 5, 5, 5);
            LinearLayout.LayoutParams layoutParams = new LinearLayout.LayoutParams(LinearLayout.LayoutParams.WrapContent, LinearLayout.LayoutParams.WrapContent);
            linearLayout.SetBackgroundColor(Color.White); //Convertor_Colour_Droid.parse(_card._iconRaw, false)
            layoutParams.SetMargins(0, 0, 0, 0);
            linearLayout.LayoutParameters = layoutParams;

            linearLayout.AddView(iconImage);
            if (textView.Text != "")
                linearLayout.AddView(textView);

            annotation.View = linearLayout;
            return annotation;
        }

        public class ChartPoint : ObservableObject
        {
            /*
             * properties
             */

            public string Icon { get; set; }

            public string Time { get; set; }

            public int Value { get; set; }
        }

        public abstract class ObservableObject : INotifyPropertyChanged
        {
            public event PropertyChangedEventHandler PropertyChanged;

            protected void RaisePropertyChanged(string propertyName)
            {
                var handler = PropertyChanged;
                if (handler != null)
                {
                    handler(this, new PropertyChangedEventArgs(propertyName));
                }
            }

            protected void RaisePropertyChanged(params string[] propertyNames)
            {
                foreach (var name in propertyNames)
                {
                    RaisePropertyChanged(name);
                }
            }
        }
    }



}

