﻿using System;
using System.Collections.ObjectModel;
using Android.App;
using Android.Appwidget;
using Android.Content;
using Android.Graphics;
using Android.Views;
using Android.Widget;
using Com.Syncfusion.Charts;
using static playground.Droid.MainActivity;

namespace appyweather.Droid
{
    // taken from: https://marcofolio.net/app-widget-xamarin-android/
    [BroadcastReceiver(Label = "Widget")]
    [IntentFilter(new string[] { "android.appwidget.action.APPWIDGET_UPDATE" })]
    [MetaData("android.appwidget.provider", Resource = "@xml/widget")]
    public class Widget : AppWidgetProvider
    {
        #region Fields
        protected int _layout;
        #endregion

        #region Event handlers
        public override void OnUpdate(Context context, AppWidgetManager appWidgetManager, int[] appWidgetIds)
        {
            try
            {
                _layout = playground.Droid.Resource.Layout.Widget;
                var component = new ComponentName(context, Java.Lang.Class.FromType(typeof(Widget)).Name);
                appWidgetManager.UpdateAppWidget(component, BuildRemoteViews(context, appWidgetIds));
            }
            catch (Exception ex)
            {
            }
        }
        #endregion

        #region Action methods
        private RemoteViews BuildRemoteViews(Context context, int[] appWidgetIds)
        {
            try
            {
                var widgetView = new RemoteViews(context.PackageName, _layout);
                UpdateLayout(widgetView);
                return widgetView;
            }
            catch (Exception ex)
            {
                return null;
            }
        }

        protected void UpdateLayout(RemoteViews widgetView)
        {
            try
            {
                SfChart _chart = new SfChart(Application.Context);
                _chart.DrawingCacheEnabled = true;

                var _axis_primary = new CategoryAxis();
                _axis_primary.AxisLineOffset = 10;
                _axis_primary.MajorGridLineStyle.StrokeWidth = 0;
                _axis_primary.MajorTickStyle.TickSize = 0;
                _axis_primary.MaximumLabels = 10;
                _axis_primary.LabelsIntersectAction = AxisLabelsIntersectAction.None;
                _axis_primary.LabelRotationAngle = -55;
                _axis_primary.LabelStyle.StrokeWidth = 0;
                _axis_primary.LabelStyle.TextColor = Color.White;
                _axis_primary.LabelStyle.TextSize = 12;
                _axis_primary.LineStyle.StrokeWidth = 0;
                _axis_primary.ShowMajorGridLines = false;


                var _axis_secondary = new NumericalAxis();
                int min = 0;
                int max = 25;
                _axis_secondary.MajorTickStyle.TickSize = 0;
                _axis_secondary.MajorGridLineStyle.StrokeWidth = 0;
                _axis_secondary.Maximum = max;
                _axis_secondary.Minimum = min;
                _axis_secondary.Visibility = Visibility.Gone;
                _chart.SecondaryAxis = _axis_secondary;

                var _lineSeries = new FastLineSeries();
                try
                {
                    _chart.Series.Clear();
                    _chart.Annotations.Clear();

                    _lineSeries.Color = Color.White;

                    var _data = new ObservableCollection<ChartPoint>();
                    _data.Add(new ChartPoint()
                    {
                        Time = "9",
                        Value = 18,
                    });

                    _data.Add(new ChartPoint()
                    {
                        Time = "10",
                        Value = 10,
                    });

                    _data.Add(new ChartPoint()
                    {
                        Time = "11",
                        Value = 18
                    });

                    _data.Add(new ChartPoint()
                    {
                        Time = "12",
                        Value = 20
                    });

                    _lineSeries.ItemsSource = _data;
                    _lineSeries.XBindingPath = "Time";
                    _lineSeries.YBindingPath = "Value";

                    int x = 1;
                    foreach (ChartPoint c in _data)
                    {
                        _chart.Annotations.Add(CreateAnnotation(Application.Context, x, c.Value));
                        x++;
                    }
                }
                catch (Exception ex)
                {

                }
                _chart.Series.Add(_lineSeries);
                //_chart.RedrawChart();
                //_chart.ReloadChart();
                //_chart.BuildDrawingCache();
                Android.Graphics.Bitmap bitmap = null;

                using (bitmap = _chart.DrawingCache)
                {
                    try
                    {
                        //bitmap = getBitmapFromView(_chart);
                        widgetView.SetImageViewBitmap(playground.Droid.Resource.Id.chart, bitmap);
                    }
                    finally
                    {
                        _chart.DrawingCacheEnabled = false;
                    }
                }

                widgetView.SetTextViewText(playground.Droid.Resource.Id.title, "Title!");
            }
            catch (Exception ex)
            {
            }
        }
        #endregion

        public static Bitmap getBitmapFromView(View view)
        {
            Bitmap bitmap = Bitmap.CreateBitmap(400, 400, Bitmap.Config.Argb8888);
            Canvas canvas = new Canvas(bitmap);
            view.Draw(canvas);
            return bitmap;
        }
    }
}